==> json-joy-2.17.0.tgz: package/esm/json-crdt/model/nodes.js <==
export class LogicalNodeIndex {
    constructor() {
        this.entries = new Map();
    }
    get(id) {
        const { time } = id;
        const sessionId = id.getSessionId();
        const map1 = this.entries;
        const map2 = map1.get(sessionId);
        if (!map2)
            return undefined;
        const operation = map2.get(time);
        if (operation)
            return operation;
        return undefined;
    }
    index(operation) {
        const { id } = operation;
        const sessionId = id.getSessionId();
        const { time } = id;
        let map = this.entries.get(sessionId);
        if (!map) {
            map = new Map();
            this.entries.set(sessionId, map);
        }
        map.set(time, operation);
    }
    delete(id) {
        const { time } = id;
        const timeMap = this.entries.get(id.getSessionId());
        if (!timeMap)
            return;
        timeMap.delete(time);
    }
    *iterate() {
        for (const map of this.entries.values())
            yield* map.values();
    }
    random() {
        const sessions = [...this.entries.keys()];
        if (!sessions.length)
            return null;
        const sessionId = sessions[Math.floor(Math.random() * sessions.length)];
        const map = this.entries.get(sessionId);
        const nodeCount = map.size;
        const index = Math.floor(Math.random() * nodeCount);
        let pos = 0;
        for (const node of map.values()) {
            if (pos === index)
                return node;
            pos++;
        }
        return null;
    }
}
export class ServerNodeIndex {
    constructor() {
        this.entries = new Map();
    }
    get(id) {
        return this.entries.get(id.time);
    }
    index(node) {
        const { id } = node;
        this.entries.set(id.time, node);
    }
    delete(id) {
        this.entries.delete(id.time);
    }
    *iterate() {
        yield* this.entries.values();
    }
    random() {
        const nodeCount = this.entries.size;
        const index = Math.floor(Math.random() * nodeCount);
        let pos = 0;
        for (const node of this.entries.values()) {
            if (pos === index)
                return node;
            pos++;
        }
        return null;
    }
}

==> json-joy-7.11.0.tgz: package/esm/json-crdt/model/nodes.js <==
export class LogicalNodeIndex {
    entries = new Map();
    get(id) {
        const { time } = id;
        const sessionId = id.getSessionId();
        const map1 = this.entries;
        const map2 = map1.get(sessionId);
        if (!map2)
            return undefined;
        const operation = map2.get(time);
        if (operation)
            return operation;
        return undefined;
    }
    index(operation) {
        const { id } = operation;
        const sessionId = id.getSessionId();
        const { time } = id;
        let map = this.entries.get(sessionId);
        if (!map) {
            map = new Map();
            this.entries.set(sessionId, map);
        }
        map.set(time, operation);
    }
    delete(id) {
        const { time } = id;
        const timeMap = this.entries.get(id.getSessionId());
        if (!timeMap)
            return;
        timeMap.delete(time);
    }
    *iterate() {
        for (const map of this.entries.values())
            yield* map.values();
    }
    random() {
        const sessions = [...this.entries.keys()];
        if (!sessions.length)
            return null;
        const sessionId = sessions[Math.floor(Math.random() * sessions.length)];
        const map = this.entries.get(sessionId);
        const nodeCount = map.size;
        const index = Math.floor(Math.random() * nodeCount);
        let pos = 0;
        for (const node of map.values()) {
            if (pos === index)
                return node;
            pos++;
        }
        return null;
    }
}
export class ServerNodeIndex {
    entries = new Map();
    get(id) {
        return this.entries.get(id.time);
    }
    index(node) {
        const { id } = node;
        this.entries.set(id.time, node);
    }
    delete(id) {
        this.entries.delete(id.time);
    }
    *iterate() {
        yield* this.entries.values();
    }
    random() {
        const nodeCount = this.entries.size;
        const index = Math.floor(Math.random() * nodeCount);
        let pos = 0;
        for (const node of this.entries.values()) {
            if (pos === index)
                return node;
            pos++;
        }
        return null;
    }
}
